Include "resistance_check_data.geo";


Group {
  // electrical
  DomainC_Ele = Region[ { TRACK } ];
  Dirichlet0 = Region[{VOLTAGE_GND}];
  Dirichlet1 = Region[{VOLTAGE_POS}];
}

Function {
  // electrical
  DefineConstant[
    sigm = {1000, Name "Input/Materials/3Electric conductivity",
      Label "Electric conductivity [S/m]"},
      V_imposed = {1, Name "Input/92Voltage [V]"}  ];
  sigma[DomainC_Ele] = sigm ;
}

Constraint {
  { Name ElectricScalarPotential; Type Assign;
    Case {
      { Region Dirichlet0 ; Value 0. ; }
    }
  }

// NEW
   { Name Global_Potential; Type Assign;
      Case{
         { Region Dirichlet1;     Value V_imposed; }
      }
   }
  
}

Include "Jacobian_Lib.pro"
Include "Integration_Lib.pro"
Include "Electrokinetics.pro"

Resolution {
  { Name Analysis ;
    System {
        { Name Sys_EleKin ; NameOfFormulation Electrokinetics_v ; }
    }
    Operation {
      CreateDir["res/"];
      Generate[Sys_EleKin] ; Solve[Sys_EleKin] ; SaveSolution[Sys_EleKin] ;
    }
  }
}

PostOperation {
  { Name Map_Results; NameOfPostProcessing Electrokinetics;
    Operation {
      Print[ v, OnElementsOf DomainC_Ele, File "res/v.pos"] ;
      Print[ j, OnElementsOf DomainC_Ele, File "res/j.pos"] ;
//      Print[ J_Mag, OnElementsOf DomainC_Ele, File "res/J_Mag.pos"] ;

//NEW
      Print[ I, OnRegion Dirichlet1, Color "AliceBlue", 
	    Format Table, SendToServer "Output/PCB_Track/Current [A]" ];
      Print[ R, OnRegion Dirichlet1, Color "AliceBlue", 
	    Format Table, SendToServer "Output/PCB_Track/Resistance [Ohm]" ];      
    }
  }
}
